@@ -17,8 +17,8 @@
     02110-1301, USA.
 */
 
-#ifndef MAILTRANSPORT_SMTPTRANSPORTCONFIGDIALOG_H
-#define MAILTRANSPORT_SMTPTRANSPORTCONFIGDIALOG_H
+#ifndef MAILTRANSPORT_SMTPCONFIGDIALOG_H
+#define MAILTRANSPORT_SMTPCONFIGDIALOG_H
 
 #include <QDialog>
 
